@@ -10,7 +10,7 @@ use IO::Socket;
 use GPS::gpsd::Point;
 use GPS::gpsd::Satellite;
 
-$VERSION = sprintf("%d.%02d", q{Revision: 0.13} =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q{Revision: 0.8} =~ /(\d+)\.(\d+)/);
 
 sub new {
   my $this = shift;
@@ -29,7 +29,7 @@ sub initialize {
   unless ($param{'do_not_init'}) { #for testing
     my $data=$self->retrieve('LKIFCB');
     foreach (keys %$data) {
-      $self->{$_}=[@{$data->{$_}}]; #there has got to be a better way to do this...
+      $self->{$_}=$data->{$_};
     }
   }
 }
@@ -44,7 +44,7 @@ sub subscribe {
     my $point=$self->get();
     if (defined($point) and $point->fix) { #if gps fix
       my $return=&{$handler}($last, $point, $config);
-      if (defined($return)) {
+      if ($return) {
         $last=$return;
       }
     }
@@ -56,8 +56,18 @@ sub default_handler {
   my $p1=shift(); #last true return or undef if first
   my $p2=shift(); #current fix
   my $config=shift(); #configuration data
-  print $p2->lat, " ", $p2->lon,"\n";
-  return $p2;
+  if (defined($p1)) {
+    if (rand(1) < 0.5) {
+      print "\n",$p1->lat," ",$p1->lon," -> ",$p2->lat," ",$p2->lon,"\n";
+      return $p2;
+    } else {
+      {local $|=1; print ".";}
+      return undef();
+    }
+  } else {
+    print "First: ",$p2->lat," ",$p2->lon,"\n";
+    return $p2;
+  }
 }
 
 sub getsatellitelist {
